using System;
using System.Diagnostics;

#pragma warning disable CS1591 // Disable warning: 'Missing XML comment for publicly visible type or member'
#pragma warning disable CS1573 // Disable warning: 'Parameter has no matching param tag in the XML comment'

namespace Godot
{
    /// <summary>
    /// <para>Custom code to generate previews. Please check <c>file_dialog/thumbnail_size</c> in <see cref="Godot.EditorSettings"/> to find out the right size to do previews at.</para>
    /// </summary>
    public partial class EditorResourcePreviewGenerator : Reference
    {
        private const string nativeName = "EditorResourcePreviewGenerator";

        public EditorResourcePreviewGenerator() : this(true)
        {
            if (ptr == IntPtr.Zero)
                ptr = EditorNativeCalls.godot_icall_EditorResourcePreviewGenerator_Ctor(this);
        }

        internal EditorResourcePreviewGenerator(bool memoryOwn) : base(memoryOwn) {}

        /// <summary>
        /// <para>If this function returns <c>true</c>, the generator will call <see cref="Godot.EditorResourcePreviewGenerator.Generate"/> or <see cref="Godot.EditorResourcePreviewGenerator.GenerateFromPath"/> for small previews as well.</para>
        /// <para>By default, it returns <c>false</c>.</para>
        /// </summary>
        [GodotMethod("can_generate_small_preview")]
        public virtual bool CanGenerateSmallPreview()
        {
            return default(bool);
        }

        /// <summary>
        /// <para>Generate a preview from a given resource with the specified size. This must always be implemented.</para>
        /// <para>Returning an empty texture is an OK way to fail and let another generator take care.</para>
        /// <para>Care must be taken because this function is always called from a thread (not the main thread).</para>
        /// </summary>
        [GodotMethod("generate")]
        public virtual Texture Generate(Resource from, Vector2 size)
        {
            return default(Texture);
        }

        /// <summary>
        /// <para>Generate a preview directly from a path with the specified size. Implementing this is optional, as default code will load and call <see cref="Godot.EditorResourcePreviewGenerator.Generate"/>.</para>
        /// <para>Returning an empty texture is an OK way to fail and let another generator take care.</para>
        /// <para>Care must be taken because this function is always called from a thread (not the main thread).</para>
        /// </summary>
        [GodotMethod("generate_from_path")]
        public virtual Texture GenerateFromPath(string path, Vector2 size)
        {
            return default(Texture);
        }

        /// <summary>
        /// <para>If this function returns <c>true</c>, the generator will automatically generate the small previews from the normal preview texture generated by the methods <see cref="Godot.EditorResourcePreviewGenerator.Generate"/> or <see cref="Godot.EditorResourcePreviewGenerator.GenerateFromPath"/>.</para>
        /// <para>By default, it returns <c>false</c>.</para>
        /// </summary>
        [GodotMethod("generate_small_preview_automatically")]
        public virtual bool GenerateSmallPreviewAutomatically()
        {
            return default(bool);
        }

        /// <summary>
        /// <para>Returns <c>true</c> if your generator supports the resource of type <c>type</c>.</para>
        /// </summary>
        [GodotMethod("handles")]
        public virtual bool Handles(string type)
        {
            return default(bool);
        }
    }
}

#pragma warning restore CS1591
#pragma warning restore CS1573
